//Communication
#define COM1_PORT 0
#define COM2_PORT 1
#define COM3_PORT 2
#define COM4_PORT 3
#define COM5_PORT 4
#define COM6_PORT 5


#define TIMER_PERIOD 50//timer period in ms (should always be smaller than REMOTE_MANUAL_MODE_TRANSMIT_PERIOD and REMOTE_AUTO_MODE_TRANSMIT_PERIOD)

#define MAX_PACKET_LENGTH 255//maximum length of a packet (in bytes) that can be received or transmitted

#define START_BYTE 0xAA//the start byte of every packet received or sent

#define PREAMBLE_INDEX   0//preamble character index
#define LENGTH_INDEX     1//this define represents which index in the packet that is received represents the byte which holds the length of this packet 
#define ID_INDEX         2//indicates what is the ID of the packet 

//the next defines are all the IDs of the packets that can be received or sent
#define DEBUG_STR_ID       (byte)9//for showing a string of characters  (by the debug window)
#define DEBUG_BUFFER_ID    (byte)10//for showing buffer of data (by the debug window)
#define RESEARCH_KIT_ID    (byte)11

//all types of packets that can be sent/received
#define RESEARCH_KIT_STOP_ID              (byte)1//from robot to PC - indication that robot stopped
#define RESEARCH_KIT_NAVIGATION_ID        (byte)2//manual navigation 
#define RESEARCH_KIT_ROBOT_INFO_ID        (byte)3//get required information from the robot
#define RESEARCH_KIT_ROBOT_MOTOR_ID       (byte)4//control the robot's motors
#define RESEARCH_KIT_ROBOT_PC_ACK_ID      (byte)5//from robot to PC - acknowledge
#define RESEARCH_KIT_ROBOT_BUZZER_ID      (byte)6//control the robot's buzzer
#define RESEARCH_KIT_DUMMY_ID             (byte)7//dummy packet (does nothing) - just to maintain communication from PC to the robot if needed
#define RESEARCH_KIT_END_PROG_MODE        (byte)8//from PC to robot - end the programming mode 

//defines for the m_drive_motor_cmnd_end_reason variables
#define RESEARCH_KIT_DRIVE_MOV_BUMPER_EVENT     1//bumper event
#define RESEARCH_KIT_DRIVE_MOV_STAIR_EVENT      2//stair event
#define RESEARCH_KIT_DRIVE_MOV_DIST             3//distance reached
#define RESEARCH_KIT_DRIVE_MOV_ULTRASOUND_EVENT 4//ultrasound event
#define RESEARCH_KIT_DRIVE_MOV_ANGLE            5//desired heading reached

///////////////////////////////////////////////////////////////////////////////////////////////
//defines for the RESEARCH_KIT_ROBOT_INFO_ID packet information
//

#define RESEARCH_KIT_ROBOT_INF_PERIOD        0//period in 50ms resolution we should transmit the requested robot information
#define RESEARCH_KIT_ROBOT_INF_PARAM1_BITMAP 1//the parameter #1 which represents what data we should transmit
#define RESEARCH_KIT_ROBOT_INF_PARAM2_BITMAP 2//the parameter #2 which represents what data we should transmit
#define RESEARCH_KIT_ROBOT_INF_PARAM3_BITMAP 3//the parameter #3 which represents what data we should transmit
#define RESEARCH_KIT_ROBOT_INF_PARAM4_BITMAP 4//the parameter #4 which represents what data we should transmit
#define RESEARCH_KIT_ROBOT_INF_ARR_SIZE      5//size of the m_info_2_transmit array

//the following defines represents the bit number in the first telemetry format byte
#define RESEARCH_KIT_US_INFO                        (byte)0//ultrasound sensors
#define RESEARCH_KIT_ODOMETER_INFO                  (byte)1//odometer
#define RESEARCH_KIT_LEFT_BMP_INFO                  (byte)2//left bumper
#define RESEARCH_KIT_RIGHT_BMP_INFO                 (byte)3//right bumper
#define RESEARCH_KIT_NO_LEFT_NOZZLE_BMP_INFO        (byte)4//normaly open left nozzle bumper
#define RESEARCH_KIT_NO_RIGHT_NOZZLE_BMP_INFO       (byte)5//normaly open right nozzle bumper
#define RESEARCH_KIT_NOZZLE_HEIGHT_INFO             (byte)6//nozzle height
#define RESEARCH_KIT_CHRG_VLT_INFO                  (byte)7//charger voltage
//the following defines represents the bit number in the second telemetry format byte
#define RESEARCH_KIT_VCC_VLT_INFO                   (byte)0//vcc power supply voltage
#define RESEARCH_KIT_AMB_TMP_INFO                   (byte)1//ambient temperature
#define RESEARCH_KIT_BRUSH_ELEVATION_INFO           (byte)2//brush elevation 
#define RESEARCH_KIT_RIGHT_DRIVE_INFO               (byte)3//right drive
#define RESEARCH_KIT_LEFT_DRIVE_INFO                (byte)4//left drive
#define RESEARCH_KIT_SELECTOR_INFO                  (byte)5//selector
#define RESEARCH_KIT_FRONT_PSD_INFO                 (byte)6//front psd
#define RESEARCH_KIT_HUMIDITY_INFO                  (byte)7//humidity
//the following defines represents the bit number in the third telemetry format byte
#define RESEARCH_KIT_BAT_VLT_INFO                   (byte)0//battery voltage
#define RESEARCH_KIT_STAIR_INFO                     (byte)1//stairs state
#define RESEARCH_KIT_BUTTONS_INFO                   (byte)2//buttons bitmap
#define RESEARCH_KIT_LEASH_INFO                     (byte)3//leash bitmap
#define RESEARCH_KIT_DOOR_INFO                      (byte)4//door bitmap
#define RESEARCH_KIT_IR_INFO                        (byte)5//IR receivers info	
#define RESEARCH_KIT_CHRG_PLUG_INFO                 (byte)6//charger plug
#define RESEARCH_KIT_CHRG_TMP_INFO                  (byte)7//charging temperature

//the following defines represents the bit number in the fourth telemetry format byte
#define RESEARCH_KIT_LEFT_BAT_THERMISTOR_INFO       (byte)0//right battery thermistor
#define RESEARCH_KIT_RIGHT_BAT_THERMISTOR_INFO      (byte)1//left battery thermistor

/////////////////////////////////////////////////////////////////////////////////////////////////

//types of drive movements for controlling the drive motor movements 
#define RESEARCH_KIT_NO_DRIVE_MOV               0
#define RESEARCH_KIT_DRIVE_MOV_STOP_TYPE        1
#define RESEARCH_KIT_DRIVE_MOV_HEAD_TYPE        2
#define RESEARCH_KIT_DRIVE_MOV_REVERSE_TYPE     3
#define RESEARCH_KIT_DRIVE_MOV_TURN_TO_TYPE     4
#define RESEARCH_KIT_DRIVE_MOV_TURN_TYPE        5
#define RESEARCH_KIT_DRIVE_MOV_CONTOUR_TYPE     6
#define RESEARCH_KIT_DRIVE_MOV_SEARCH_DOCK_TYPE 7
#define RESEARCH_KIT_DRIVE_MOV_PWM_TYPE         8//set motors PWM
#define RESEARCH_KIT_DRIVE_MOV_DIRECTION_TYPE   9//set motors direction
#define RESEARCH_KIT_DRIVE_MOV_CURVE_TYPE       10

//defines for motor commands
#define RESEARCH_KIT_SUCTION_MOTOR            0
#define RESEARCH_KIT_BRUSH_MOTOR              1
#define RESEARCH_KIT_DRIVE_MOTOR              2
#define RESEARCH_KIT_ELEVATION_MOTOR          3

//types of values 
#define BYTE_TYPE  0
#define SHORT_TYPE 1
#define LONG_TYPE  2

#define REMOTE_MANUAL_MODE_TRANSMIT_PERIOD 250//remote will send packets to robot every maximum REMOTE_MANUAL_MODE_TRANSMIT_PERIOD ms in manual mode
#define REMOTE_AUTO_MODE_TRANSMIT_PERIOD   1000//remote will send packets to robot every maximum REMOTE_AUTO_MODE_TRANSMIT_PERIOD ms in automatic mode
#define REMOTE_TRANSMIT_PERIOD             1000//remote will send packets to robot every maximum REMOTE_TRANSMIT_PERIOD ms in all modes

//indicates how much time we should wait when no navigation button is pressed before we send a command to stop the robot
#define REMOTE_POSTPONE_STOP_COMMAND_TIME   1000//in ms
#define REMOTE_POSTPONE_STOP_COMMAND_COUNT  (REMOTE_POSTPONE_STOP_COMMAND_TIME/TIMER_PERIOD)




