// File: remote control.cpp               Date: 15-NOV-2004
//

/*
  Command Line:

  /L="paths information file"

  /I="AGV device driver (DD) INI file", for example   /I="AGVVD1.INI"

  /N="n", where "n" is AGV device ID, for example   /N=2 

  /CIMDD_ONLINE - run AGV DD in online mode.

  /CIMDD_SIMUL_AUTO - run AGV DD in Simulation Automatic mode.

  /CIMDD_SIMUL_MANUAL - run AGV DD in Simulation Manual mode.

  /CIMDD_STANDALONE - run AGV DD for working without autonomous.

*/

#include "stdafx.h"
#include "remote control.h"
#include "remote controlDlg.h"
#include "communication_defs.h"

#include "vc2_funs.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif


/////////////////////////////////////////////////////////////////////////////
// CRemotecontrolApp

BEGIN_MESSAGE_MAP(CRemotecontrolApp, CWinApp)
	//{{AFX_MSG_MAP(CRemotecontrolApp)
		// NOTE - the ClassWizard will add and remove mapping macros here.
		//    DO NOT EDIT what you see in these blocks of generated code!
	//}}AFX_MSG
	ON_COMMAND(ID_HELP, CWinApp::OnHelp)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CRemotecontrolApp construction

CRemotecontrolApp::CRemotecontrolApp()
{
   cmMode = StandaloneOnly;

}//end of CRemotecontrolApp::CRemotecontrolApp()

/////////////////////////////////////////////////////////////////////////////
// The one and only CRemotecontrolApp object

CRemotecontrolApp theApp;

/////////////////////////////////////////////////////////////////////////////
// CRemotecontrolApp initialization

BOOL CRemotecontrolApp::InitInstance()
{
	if (!AfxSocketInit())
	{
		AfxMessageBox("Failed to Initialize Sockets",MB_OK| MB_ICONSTOP);
		return FALSE;
	}

	if (!AfxOleInit())
	{
		AfxMessageBox("OLE initialization failed.  Make sure that the OLE libraries are the correct version.");
		return FALSE;
	}

	AfxEnableControlContainer();

	// Standard initialization
	// If you are not using these features and wish to reduce the size
	//  of your final executable, you should remove from the following
	//  the specific initialization routines you do not need.

#ifdef _AFXDLL
	Enable3dControls();			// Call this when using MFC in a shared DLL
#else
	Enable3dControlsStatic();	// Call this when linking to MFC statically
#endif


	SetRegistryKey(_T("Intelitek - AGV Open CIM  Device Driver"));

	//get settings from the registry
	m_serial_port_id = GetProfileInt(HARDWARE_SECTION,SERIAL_PORT_ENTRY,COM1_PORT);
	m_serial_port_baud_rate = GetProfileInt(HARDWARE_SECTION,BAUD_RATE_ENTRY,CBR_38400);

	GetCurrentDirectory(MAXPATH, m_szHomeDir );
    strcat( m_szHomeDir, "\\" );

	m_strDD_INIFileName = "AGVDD.INI";
    ParseCommandLine();

	strcpy(m_szOPENCIMINI,IniReader.Init( ( char *)(LPCSTR)m_strDD_INIFileName ));	
	strcpy(m_szMapINI,"..\\SETUP\\MAP.INI");	

	for( int i = 0; i < MAX_LOGICALIDOFDEVICE; ++i ) 
	{
		m_iIdOfDevice[i] = LOGICAL_NO_ID;
	}
	
	CString strSetupPath;
	CString strTemp( m_szOPENCIMINI );
	if( strTemp.GetLength() >= 2 )
		 strSetupPath = strTemp.Left( 2 );

	CommaParserStr2IntArray( (LPSTR)(LPCTSTR)m_strDeviceIDs, m_iIdOfDevice,
								   MAX_LOGICALIDOFDEVICE,(LPSTR)(LPCTSTR)strSetupPath);

	free((void*)m_pszAppName);
	m_pszAppName=_tcsdup(_T(cszApplName));


	CRemotecontrolDlg dlg;
	m_pMainWnd = &dlg;
	int nResponse = dlg.DoModal();
	if (nResponse == IDOK)
	{
		// TODO: Place code here to handle when the dialog is
		//  dismissed with OK
	}
	else if (nResponse == IDCANCEL)
	{
		// TODO: Place code here to handle when the dialog is
		// dismissed with Cancel
	}

	// Since the dialog has been closed, return FALSE so that we exit the
	//  application, rather than start the application's message pump.
	return FALSE;
}// end of BOOL CRemotecontrolApp::InitInstance()

BOOL CRemotecontrolApp::ParseCommandLine()
{
	for( int i = 1; i < __argc; i++ )
	{
		LPCSTR pCurrentArgument = __targv[i];
		if( pCurrentArgument[0] == '/' )
             pCurrentArgument++;
		CString strArg(pCurrentArgument);

        switch( strArg[0] )
		{
			case 'I':
				m_strDD_INIFileName = strArg.Mid( 2 );
				m_strDD_INIFileName.TrimLeft();
			break;

			case 'N':
				m_strDeviceIDs = strArg.Mid( 2 );
				m_strDeviceIDs.TrimLeft();
			break;

			case 'C':
					if( strArg.CompareNoCase( "CIMDD_ONLINE" ) == 0 )
			    		cmMode = Real;
					else if( strArg.CompareNoCase( "CIMDD_SIMUL_AUTO" ) == 0 )
						cmMode = SimulAuto;
					else if( strArg.CompareNoCase( "CIMDD_SIMUL_MANUAL" ) == 0 )
						cmMode = SimulManual;
					else if( strArg.CompareNoCase( "CIMDD_STANDALONE" ) == 0 )
						cmMode = Standalone;
			break;

			case 'L':
                    m_strLoadPathsFileName = strArg.Mid( 2 );
                    m_strLoadPathsFileName.TrimLeft(); 
			break;
		}; // end of switch( pCurrentArgument[0] )

	}// end of for( int i = 1; i < __argc; i++ )

    return TRUE;
}// end of BOOL CRemotecontrolApp::ParseCommandLine()
